@@ -1,13 +1,14 @@
 """Production settings unique to the rapid response plugin."""
 
-import os
+from path import Path as path
 
-BASE_DIR = os.path.dirname(os.path.dirname(__file__))
+PLUGIN_TEMPLATES_ROOT = path(__file__).abspath().dirname().dirname()
 
 
 def plugin_settings(settings):
     """Settings for the rapid response plugin."""
-    PLUGIN_TEMPLATES_ROOT = os.path.join(BASE_DIR, "templates")
+    settings.TEMPLATES = settings.ENV_TOKENS.get("TEMPLATES", settings.TEMPLATES)
+
     for template_engine in settings.TEMPLATES:
         template_dirs = template_engine["DIRS"]
-        template_dirs.append(PLUGIN_TEMPLATES_ROOT)
+        template_dirs.append(PLUGIN_TEMPLATES_ROOT + "/templates")
